@@ -6,7 +6,7 @@
 
   Author:  Vadim Zaliva lord@crocodile.org
 
-  $Id: dns.h,v 1.3 2005/03/30 07:50:13 vkurland Exp $
+  $Id: dns.h,v 1.3.4.1 2006/03/19 06:07:24 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -92,7 +92,7 @@ class DNS : public BackgroundOp
      */
     static void init();
     
-    DNS::DNS();
+    DNS();
 
     /**
      * Finds IP adddresses of the host with given host name.
